Index: trunk/psModules/src/detrend/pmShifts.h
===================================================================
--- trunk/psModules/src/detrend/pmShifts.h	(revision 12010)
+++ trunk/psModules/src/detrend/pmShifts.h	(revision 12098)
@@ -4,16 +4,17 @@
 #include <pslib.h>
 #include "pmFPA.h"
-#include "pmFPAview.h"
 
 /// Read any orthogonal transfer shifts extension in a FITS file
 ///
-/// Given a FITS file (typically newly opened ready for processing), this function searches for the extension
-/// specified by the SHIFTS keyword within the FILE information in the camera format.  If the extension is
-/// found, the shifts table is read and translated into kernels which are placed in the analysis metadata of
-/// each cell.
-bool pmShiftsRead(psFits *fits,         ///< FITS file in which to search for OT shifts extension
-                  pmFPA *fpa,           ///< FPA containing the cells that own the shifts
-                  const pmFPAview *phuView ///< View of the PHU; specifies which chip(s) owns the cells
-    );
+/// Given a cell, this function searches for the orthogonal transfer shifts for this cell in the supplied FITS
+/// file.  The FITS extension containing the shifts table is specified by the SHIFTS keyword within the FILE
+/// information in the camera format.  If the extension is found, the shifts table is read and translated into
+/// kernels which are placed in the analysis metadata of each cell.  Note that this operation is performed on
+/// all cells within the FITS file (or at least, those contained within the shifts table), not just the cell
+/// provided --- if we have to read the whole table, we may as well translate the whole lot.  If a kernel is
+/// already present in the cell analysis metadata, the function returns true without doing any work.
+bool pmShiftsRead(pmCell *cell,         ///< Cell for which to search for shifts
+                  psFits *fits          ///< FITS file in which to search for OT shifts extension
+                  );
 
 
@@ -4,16 +4,17 @@
 
-/// Read any orthogonal transfer shifts extension in a FITS file
+/// Read orthogonal transfer shifts table for a cell
 ///
